
ifeq ($(INSTALL_DIR),)
  $(error "Please provide the INSTALL_DIR value")
endif

.PHONY: $(ARCHIVE)

parent_name = $(lastword $(subst /, ,$(abspath $1)))
QT_VERSION := $(call parent_name,$(INSTALL_DIR))

parent_dir = $(dir $(abspath $1))
INSTALL_PARENT_DIR := $(call parent_dir,$(INSTALL_DIR))

DATE := $(shell date "+%Y-%m-%dT%H_%M")
HOST := $(shell hostname)

include ../../../current/allmake.mak

BUILD_DIR:=build/$(BINDIR)
DIST_DIR:=dist/$(BINDIR)

ifdef __NT__
  ARCHIVE_FORMAT:=zip
  # MUST BE RUN IN A VS SHELL!
  CL_VERSION := $(VisualStudioVersion)
  CC_VERSION := $(CL_VERSION)
  PLATFORM := Windows
  INSTALL_LIB_DIR := $(INSTALL_DIR)/bin
  qtdll_fname = Qt5$1.dll
else
  ARCHIVE_FORMAT:=tar.bz2
  ifdef __LINUX__
    CC_VERSION := $(GCC_VERSION)
    PLATFORM_ID := $(shell lsb_release -si)
    PLATFORM_RELEASE := $(shell lsb_release -sr)
    PLATFORM := $(PLATFORM_ID)_$(PLATFORM_RELEASE)
    INSTALL_LIB_DIR := $(INSTALL_DIR)/lib
    PATCHELF = patchelf --set-rpath '$$ORIGIN/../../' $@
    qtdll_fname = libQt5$1.so.5
  else
    PLATFORM := Darwin
    CC_VERSION := $(shell $(CC) -dumpversion)
  endif
endif

ifeq ($(QT_VERSION),)
  $(error "Couldn't derive Qt version")
endif
ifeq ($(DATE),)
  $(error "Couldn't get date")
endif
ifeq ($(PLATFORM),)
  $(error "Couldn't get platform")
endif
ifeq ($(HOST),)
  $(error "Couldn't get host")
endif
ifeq ($(CC_VERSION),)
  $(error "Couldn't get compiler version")
endif
ifeq ($(ARCHIVE_FORMAT),)
  $(error "Bad archive format")
endif

ARCHIVE := $(abspath qt-$(QT_VERSION)-$(DATE)-$(PLATFORM)-$(HOST)-$(COMPILER_NAME)$(CC_VERSION).$(ARCHIVE_FORMAT))

all: $(ARCHIVE)

$(ARCHIVE):
ifdef __NT__
	(cd $(INSTALL_PARENT_DIR) && zip -r $@ $(QT_VERSION))
else
	(cd $(INSTALL_PARENT_DIR) && tar cjf $@ $(QT_VERSION))
endif
